%feature("docstring") OT::CorrelationAnalysis::PCC
"Correlation evaluation based on the Partial Correlation Coefficient.

Refer to :ref:`ranking_pcc`.

Parameters
----------
sample1 : 2-d sequence of float
    First sample, of dimension :math:`n \\geq 2`.
sample2 : 2-d sequence of float
    Second sample, of dimension = 1.

Returns
-------
coef : :class:`~openturns.Point`
    The PCC coefficients evaluated between the *sample2* and each coordinate of
    *sample1*.

See Also
--------
CorrelationAnalysis_PearsonCorrelation, CorrelationAnalysis_SRC, 
CorrelationAnalysis_PRCC"

// ---------------------------------------------------------------------

%feature("docstring") OT::CorrelationAnalysis::PRCC
"Correlation evaluation based on the Partial Rank Correlation Coefficient.

Refer to :ref:`ranking_prcc`.

Parameters
----------
sample1 : 2-d sequence of float
    First sample, of dimension :math:`n \\geq 2`.
sample2 : 2-d sequence of float
    Second sample, of dimension = 1.

Returns
-------
coef : :class:`~openturns.Point`
    The PRCC coefficients evaluated between the *sample2* and each coordinate of
    *sample1* (based on the rank values).

See Also
--------
CorrelationAnalysis_SpearmanCorrelation, CorrelationAnalysis_SRRC,
CorrelationAnalysis_PCC"

// ---------------------------------------------------------------------

%feature("docstring") OT::CorrelationAnalysis::PearsonCorrelation
"Correlation evaluation based on the Pearson correlation coefficient.

Refer to :ref:`pearson_coefficient`.

Parameters
----------
sample1 : 2-d sequence of float
    First sample
sample2 : 2-d sequence of float
    Second sample, of dimension = 1.

Returns
-------
coef : :class:`~openturns.Point`
    The Pearson coefficients evaluated between the *sample2* and each coordinate of
    *sample1*.

See Also
--------
CorrelationAnalysis_PCC, CorrelationAnalysis_SRC,
CorrelationAnalysis_SpearmanCorrelation"

// ---------------------------------------------------------------------

%feature("docstring") OT::CorrelationAnalysis::SpearmanCorrelation
"Correlation evaluation based on the Spearman correlation coefficient.

Refer to :ref:`spearman_coefficient`.

Parameters
----------
sample1 : 2-d sequence of float
    First sample
sample2 : 2-d sequence of float
    Second sample, of dimension = 1.

Returns
-------
coef : :class:`~openturns.Point`
    The Spearman coefficients evaluated between the *sample2* and each coordinate of
    *sample1* (based on the rank values).

See Also
--------
CorrelationAnalysis_PRCC, CorrelationAnalysis_SRRC,
CorrelationAnalysis_PearsonCorrelation"

// ---------------------------------------------------------------------

%feature("docstring") OT::CorrelationAnalysis::SRC
"Correlation evaluation based on the Standard Regression Coefficient.

Refer to :ref:`ranking_src`.

Parameters
----------
sample1 : 2-d sequence of float
    First sample, of dimension :math:`n \\geq 1`.
sample2 : 2-d sequence of float
    Second sample, of dimension = 1.
normalize : bool
    if True, coefficients sum to one.
    Otherwise it includes noise variance
    Default value is false.

Returns
-------
coef : :class:`~openturns.Point`
    The SRC evaluated between the *sample2* and each coordinate of the *sample1*.

See Also
--------
CorrelationAnalysis_PearsonCorrelation, CorrelationAnalysis_PCC,
CorrelationAnalysis_SRRC"

// ---------------------------------------------------------------------

%feature("docstring") OT::CorrelationAnalysis::SRRC
"Correlation evaluation based on the Standard Rank Regression Coefficient.

Similar as SRC evaluated on the ranked samples.

Parameters
----------
sample1 : 2-d sequence of float
    First sample, of dimension :math:`n \\geq 1`.
sample2 : 2-d sequence of float
    Second sample, of dimension = 1.
normalize : bool
    if True, coefficients sum to one.
    Otherwise it includes noise variance
    Default value is false.

Returns
-------
coef : :class:`~openturns.Point`
    The SRRC evaluated between the *sample2* and each coordinate of the
    *sample1* (based on the rank value).

See Also
--------
CorrelationAnalysis_SpearmanCorrelation, CorrelationAnalysis_PRCC,
CorrelationAnalysis_SRC"

// ---------------------------------------------------------------------

%feature("docstring") OT::CorrelationAnalysis::SignedSRC
"Correlation evaluation based on the Signed Standard Rank Regression Coefficient.

It takes into account the linear coefficient sign.

Parameters
----------
sample1 : 2-d sequence of float
    First sample, of dimension :math:`n \\geq 1`.
sample2 : 2-d sequence of float
    Second sample, of dimension = 1.

Returns
-------
coef : :class:`~openturns.Point`
    The SRC evaluated between the *sample2* and each coordinate of the
    *sample1* (based on the rank value).

See Also
--------
CorrelationAnalysis_SpearmanCorrelation, CorrelationAnalysis_PRCC,
CorrelationAnalysis_SRC, CorrelationAnalysis_SRRC"
